==> kubernetes-model-core-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/NFSVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface NFSVolumeSourceFluent<A extends NFSVolumeSourceFluent<A>> extends Fluent<A> {


    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    public A withNewPath(StringBuilder arg1);
    public A withNewPath(int[] arg1,int arg2,int arg3);
    public A withNewPath(char[] arg1);
    public A withNewPath(StringBuffer arg1);
    public A withNewPath(byte[] arg1,int arg2);
    public A withNewPath(byte[] arg1);
    public A withNewPath(char[] arg1,int arg2,int arg3);
    public A withNewPath(byte[] arg1,int arg2,int arg3);
    public A withNewPath(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewPath(String arg1);
    public Boolean getReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
    public String getServer();
    public A withServer(String server);
    public Boolean hasServer();
    public A withNewServer(StringBuilder arg1);
    public A withNewServer(int[] arg1,int arg2,int arg3);
    public A withNewServer(char[] arg1);
    public A withNewServer(StringBuffer arg1);
    public A withNewServer(byte[] arg1,int arg2);
    public A withNewServer(byte[] arg1);
    public A withNewServer(char[] arg1,int arg2,int arg3);
    public A withNewServer(byte[] arg1,int arg2,int arg3);
    public A withNewServer(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewServer(String arg1);
}

==> kubernetes-model-core-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/NFSVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface NFSVolumeSourceFluent<A extends NFSVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    public A withNewPath(StringBuilder arg1);
    public A withNewPath(int[] arg1,int arg2,int arg3);
    public A withNewPath(char[] arg1);
    public A withNewPath(StringBuffer arg1);
    public A withNewPath(byte[] arg1,int arg2);
    public A withNewPath(byte[] arg1);
    public A withNewPath(char[] arg1,int arg2,int arg3);
    public A withNewPath(byte[] arg1,int arg2,int arg3);
    public A withNewPath(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewPath(String arg1);
    public Boolean getReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
    public String getServer();
    public A withServer(String server);
    public Boolean hasServer();
    public A withNewServer(StringBuilder arg1);
    public A withNewServer(int[] arg1,int arg2,int arg3);
    public A withNewServer(char[] arg1);
    public A withNewServer(StringBuffer arg1);
    public A withNewServer(byte[] arg1,int arg2);
    public A withNewServer(byte[] arg1);
    public A withNewServer(char[] arg1,int arg2,int arg3);
    public A withNewServer(byte[] arg1,int arg2,int arg3);
    public A withNewServer(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewServer(String arg1);
}
